# -*- coding: utf-8 -*-
from odoo.tests import new_test_user, tagged
from odoo.addons.base.tests.common import HttpCaseWithUserPortal
from .common import EnterpriseDatabaseCommon


@tagged('post_install', '-at_install')
class TestMyDatabases(HttpCaseWithUserPortal, EnterpriseDatabaseCommon):

    def setUp(self):
        super().setUp()

        self.partner_accounting_firm = self.env['res.partner'].create({
            'name': 'Test Accounting Firm',
            'portal_accounting_firm_level': '0_learning',
            'is_published': True,
        })
        self.user_accountant = new_test_user(
            self.env,
            login='accountant@accounting-firm.tld',
            groups='base.group_portal',
            parent_id=self.partner_accounting_firm.id,
        )

        self.database = self.create_database()
        self.send_ping(self.database.db_uuid, {}, payload_update={
            'dbname': 'my_test_database',
            'apps': ['mail', 'account'],
            'version': '16.0+e',
            'users': [
                {'login': self.user_accountant.login,
                 'name': self.user_accountant.name,
                 'is_admin': True,
                 'odoo_com_uid': str(self.user_accountant.id)},
            ],
        })

    def test_no_accounting_firm_features_for_normal_user(self):
        self.user_accountant.portal_accounting_firm_level = False
        self.partner_accounting_firm.portal_accounting_firm_level = False
        self.start_tour("/", 'my_databases_check_no_accounting_firm_features', login=self.user_accountant.login)

    def test_no_accounting_firm_features_for_unpublished_firm(self):
        self.partner_accounting_firm.is_published = False
        self.start_tour("/", 'my_databases_check_no_accounting_firm_features', login=self.user_accountant.login)

    def test_invite_users(self):
        new_test_user(
            self.env,
            login='colleague@domain.tld',
            groups='base.group_portal',
            parent_id=self.partner_accounting_firm.id,
        )
        self.start_tour("/", 'my_databases_invite_users', login=self.user_accountant.login)
